@@ -947,7 +947,7 @@ class RedisModel:
     
     def _fill_fields_values(self, field_values_dict):
         for name, value in field_values_dict.items():
-            fields = self.get('fields')
+            fields = self.__model_data__['fields']
             if name in fields.keys():
                 fields[name].value = value
             else:
